# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import api_token_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.api_token import APIToken
from ..types.api_token_list_response import APITokenListResponse

__all__ = ["APITokensResource", "AsyncAPITokensResource"]


class APITokensResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> APITokensResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return APITokensResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> APITokensResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return APITokensResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APIToken:
        """
        Create a new API token for the authenticated organization.

        Args:
          name: The name that will be used to identify the API token.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api-tokens",
            body=maybe_transform({"name": name}, api_token_create_params.APITokenCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APIToken,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APIToken:
        """Get an API token by its ID (e.g.

        `token_123`). The token must belong to the
        authenticated user's organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/api-tokens/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APIToken,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APITokenListResponse:
        """List all API tokens for the authenticated user's organization."""
        return self._get(
            "/api-tokens",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APITokenListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Revoke a specific API Token for the authenticated organization.

        After
        revocation, the token will no longer be valid and cannot be used to authenticate
        requests.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/api-tokens/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAPITokensResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAPITokensResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAPITokensResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAPITokensResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return AsyncAPITokensResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APIToken:
        """
        Create a new API token for the authenticated organization.

        Args:
          name: The name that will be used to identify the API token.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api-tokens",
            body=await async_maybe_transform({"name": name}, api_token_create_params.APITokenCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APIToken,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APIToken:
        """Get an API token by its ID (e.g.

        `token_123`). The token must belong to the
        authenticated user's organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/api-tokens/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APIToken,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> APITokenListResponse:
        """List all API tokens for the authenticated user's organization."""
        return await self._get(
            "/api-tokens",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=APITokenListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Revoke a specific API Token for the authenticated organization.

        After
        revocation, the token will no longer be valid and cannot be used to authenticate
        requests.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/api-tokens/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class APITokensResourceWithRawResponse:
    def __init__(self, api_tokens: APITokensResource) -> None:
        self._api_tokens = api_tokens

        self.create = to_raw_response_wrapper(
            api_tokens.create,
        )
        self.retrieve = to_raw_response_wrapper(
            api_tokens.retrieve,
        )
        self.list = to_raw_response_wrapper(
            api_tokens.list,
        )
        self.delete = to_raw_response_wrapper(
            api_tokens.delete,
        )


class AsyncAPITokensResourceWithRawResponse:
    def __init__(self, api_tokens: AsyncAPITokensResource) -> None:
        self._api_tokens = api_tokens

        self.create = async_to_raw_response_wrapper(
            api_tokens.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            api_tokens.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            api_tokens.list,
        )
        self.delete = async_to_raw_response_wrapper(
            api_tokens.delete,
        )


class APITokensResourceWithStreamingResponse:
    def __init__(self, api_tokens: APITokensResource) -> None:
        self._api_tokens = api_tokens

        self.create = to_streamed_response_wrapper(
            api_tokens.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            api_tokens.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            api_tokens.list,
        )
        self.delete = to_streamed_response_wrapper(
            api_tokens.delete,
        )


class AsyncAPITokensResourceWithStreamingResponse:
    def __init__(self, api_tokens: AsyncAPITokensResource) -> None:
        self._api_tokens = api_tokens

        self.create = async_to_streamed_response_wrapper(
            api_tokens.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            api_tokens.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            api_tokens.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            api_tokens.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .graphs import (
    GraphsResource,
    AsyncGraphsResource,
    GraphsResourceWithRawResponse,
    AsyncGraphsResourceWithRawResponse,
    GraphsResourceWithStreamingResponse,
    AsyncGraphsResourceWithStreamingResponse,
)
from .queries import (
    QueriesResource,
    AsyncQueriesResource,
    QueriesResourceWithRawResponse,
    AsyncQueriesResourceWithRawResponse,
    QueriesResourceWithStreamingResponse,
    AsyncQueriesResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)
from .api_tokens import (
    APITokensResource,
    AsyncAPITokensResource,
    APITokensResourceWithRawResponse,
    AsyncAPITokensResourceWithRawResponse,
    APITokensResourceWithStreamingResponse,
    AsyncAPITokensResourceWithStreamingResponse,
)

__all__ = [
    "APITokensResource",
    "AsyncAPITokensResource",
    "APITokensResourceWithRawResponse",
    "AsyncAPITokensResourceWithRawResponse",
    "APITokensResourceWithStreamingResponse",
    "AsyncAPITokensResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
    "GraphsResource",
    "AsyncGraphsResource",
    "GraphsResourceWithRawResponse",
    "AsyncGraphsResourceWithRawResponse",
    "GraphsResourceWithStreamingResponse",
    "AsyncGraphsResourceWithStreamingResponse",
    "QueriesResource",
    "AsyncQueriesResource",
    "QueriesResourceWithRawResponse",
    "AsyncQueriesResourceWithRawResponse",
    "QueriesResourceWithStreamingResponse",
    "AsyncQueriesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional

import httpx

from .tuples import (
    TuplesResource,
    AsyncTuplesResource,
    TuplesResourceWithRawResponse,
    AsyncTuplesResourceWithRawResponse,
    TuplesResourceWithStreamingResponse,
    AsyncTuplesResourceWithStreamingResponse,
)
from ...types import document_create_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .contents import (
    ContentsResource,
    AsyncContentsResource,
    ContentsResourceWithRawResponse,
    AsyncContentsResourceWithRawResponse,
    ContentsResourceWithStreamingResponse,
    AsyncContentsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.document import Document
from ...types.document_list_response import DocumentListResponse

__all__ = ["DocumentsResource", "AsyncDocumentsResource"]


class DocumentsResource(SyncAPIResource):
    @cached_property
    def contents(self) -> ContentsResource:
        return ContentsResource(self._client)

    @cached_property
    def tuples(self) -> TuplesResource:
        return TuplesResource(self._client)

    @cached_property
    def with_raw_response(self) -> DocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return DocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return DocumentsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        file: Optional[Iterable[int]] | NotGiven = NOT_GIVEN,
        text: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Document:
        """Create a new document.

        Unlike other endpoints, this endpoint requires data to be
        sent as `multipart/form-data` rather than JSON.

        Args:
          name: The name of the document

          file: The file content of the document

          text: The text content of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/documents",
            body=maybe_transform(
                {
                    "name": name,
                    "file": file,
                    "text": text,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Document,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Document:
        """
        Get metadata for a single document by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Document,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DocumentListResponse:
        """List all documents for the authenticated user's organization."""
        return self._get(
            "/documents",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a document by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncDocumentsResource(AsyncAPIResource):
    @cached_property
    def contents(self) -> AsyncContentsResource:
        return AsyncContentsResource(self._client)

    @cached_property
    def tuples(self) -> AsyncTuplesResource:
        return AsyncTuplesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncDocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return AsyncDocumentsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        file: Optional[Iterable[int]] | NotGiven = NOT_GIVEN,
        text: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Document:
        """Create a new document.

        Unlike other endpoints, this endpoint requires data to be
        sent as `multipart/form-data` rather than JSON.

        Args:
          name: The name of the document

          file: The file content of the document

          text: The text content of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/documents",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "file": file,
                    "text": text,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Document,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Document:
        """
        Get metadata for a single document by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Document,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DocumentListResponse:
        """List all documents for the authenticated user's organization."""
        return await self._get(
            "/documents",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a document by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class DocumentsResourceWithRawResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.create = to_raw_response_wrapper(
            documents.create,
        )
        self.retrieve = to_raw_response_wrapper(
            documents.retrieve,
        )
        self.list = to_raw_response_wrapper(
            documents.list,
        )
        self.delete = to_raw_response_wrapper(
            documents.delete,
        )

    @cached_property
    def contents(self) -> ContentsResourceWithRawResponse:
        return ContentsResourceWithRawResponse(self._documents.contents)

    @cached_property
    def tuples(self) -> TuplesResourceWithRawResponse:
        return TuplesResourceWithRawResponse(self._documents.tuples)


class AsyncDocumentsResourceWithRawResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.create = async_to_raw_response_wrapper(
            documents.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            documents.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            documents.list,
        )
        self.delete = async_to_raw_response_wrapper(
            documents.delete,
        )

    @cached_property
    def contents(self) -> AsyncContentsResourceWithRawResponse:
        return AsyncContentsResourceWithRawResponse(self._documents.contents)

    @cached_property
    def tuples(self) -> AsyncTuplesResourceWithRawResponse:
        return AsyncTuplesResourceWithRawResponse(self._documents.tuples)


class DocumentsResourceWithStreamingResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.create = to_streamed_response_wrapper(
            documents.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            documents.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            documents.list,
        )
        self.delete = to_streamed_response_wrapper(
            documents.delete,
        )

    @cached_property
    def contents(self) -> ContentsResourceWithStreamingResponse:
        return ContentsResourceWithStreamingResponse(self._documents.contents)

    @cached_property
    def tuples(self) -> TuplesResourceWithStreamingResponse:
        return TuplesResourceWithStreamingResponse(self._documents.tuples)


class AsyncDocumentsResourceWithStreamingResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.create = async_to_streamed_response_wrapper(
            documents.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            documents.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            documents.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            documents.delete,
        )

    @cached_property
    def contents(self) -> AsyncContentsResourceWithStreamingResponse:
        return AsyncContentsResourceWithStreamingResponse(self._documents.contents)

    @cached_property
    def tuples(self) -> AsyncTuplesResourceWithStreamingResponse:
        return AsyncTuplesResourceWithStreamingResponse(self._documents.tuples)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["APIToken"]


class APIToken(BaseModel):
    id: str
    """The ID of the API token. Starts with prefix `token_`."""

    created_at: str
    """
    The date and time when the API token was created in
    [RFC 3339](https://www.rfc-editor.org/rfc/rfc3339) format.
    """

    name: str
    """The human-readable name of the API token."""

    owner: str
    """The owner of the API token, either an organization or a user."""

    token_prefix: str
    """The 8-character prefix of the token itself."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .graph import Graph as Graph
from .document import Document as Document
from .api_token import APIToken as APIToken
from .query_response import QueryResponse as QueryResponse
from .document_contents import DocumentContents as DocumentContents
from .graph_query_params import GraphQueryParams as GraphQueryParams
from .client_query_params import ClientQueryParams as ClientQueryParams
from .graph_create_params import GraphCreateParams as GraphCreateParams
from .graph_list_response import GraphListResponse as GraphListResponse
from .graph_tuples_params import GraphTuplesParams as GraphTuplesParams
from .query_decode_params import QueryDecodeParams as QueryDecodeParams
from .graph_query_response import GraphQueryResponse as GraphQueryResponse
from .graph_tuples_response import GraphTuplesResponse as GraphTuplesResponse
from .health_check_response import HealthCheckResponse as HealthCheckResponse
from .query_decode_response import QueryDecodeResponse as QueryDecodeResponse
from .document_create_params import DocumentCreateParams as DocumentCreateParams
from .document_list_response import DocumentListResponse as DocumentListResponse
from .api_token_create_params import APITokenCreateParams as APITokenCreateParams
from .api_token_list_response import APITokenListResponse as APITokenListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel
from .api_token import APIToken

__all__ = ["APITokenListResponse"]


class APITokenListResponse(BaseModel):
    api_tokens: List[APIToken]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tuples import (
    TuplesResource,
    AsyncTuplesResource,
    TuplesResourceWithRawResponse,
    AsyncTuplesResourceWithRawResponse,
    TuplesResourceWithStreamingResponse,
    AsyncTuplesResourceWithStreamingResponse,
)
from .contents import (
    ContentsResource,
    AsyncContentsResource,
    ContentsResourceWithRawResponse,
    AsyncContentsResourceWithRawResponse,
    ContentsResourceWithStreamingResponse,
    AsyncContentsResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)

__all__ = [
    "ContentsResource",
    "AsyncContentsResource",
    "ContentsResourceWithRawResponse",
    "AsyncContentsResourceWithRawResponse",
    "ContentsResourceWithStreamingResponse",
    "AsyncContentsResourceWithStreamingResponse",
    "TuplesResource",
    "AsyncTuplesResource",
    "TuplesResourceWithRawResponse",
    "AsyncTuplesResourceWithRawResponse",
    "TuplesResourceWithStreamingResponse",
    "AsyncTuplesResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.documents import tuple_list_params

__all__ = ["TuplesResource", "AsyncTuplesResource"]


class TuplesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TuplesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return TuplesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TuplesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return TuplesResourceWithStreamingResponse(self)

    def list(
        self,
        id: str,
        *,
        stream: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Extract tuples from a document by its ID.

        If streaming is enabled, the response
        will be a stream of tuples as JSON server-sent events. This endpoint requires
        calling our external inference service, and will have significant latency.

        Args:
          stream: Whether to stream the tuples back as a stream of JSON server-sent events

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/documents/{id}/tuples",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"stream": stream}, tuple_list_params.TupleListParams),
            ),
            cast_to=NoneType,
        )


class AsyncTuplesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTuplesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTuplesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTuplesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tractorbeamai/tractorbeam-python#with_streaming_response
        """
        return AsyncTuplesResourceWithStreamingResponse(self)

    async def list(
        self,
        id: str,
        *,
        stream: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Extract tuples from a document by its ID.

        If streaming is enabled, the response
        will be a stream of tuples as JSON server-sent events. This endpoint requires
        calling our external inference service, and will have significant latency.

        Args:
          stream: Whether to stream the tuples back as a stream of JSON server-sent events

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/documents/{id}/tuples",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"stream": stream}, tuple_list_params.TupleListParams),
            ),
            cast_to=NoneType,
        )


class TuplesResourceWithRawResponse:
    def __init__(self, tuples: TuplesResource) -> None:
        self._tuples = tuples

        self.list = to_raw_response_wrapper(
            tuples.list,
        )


class AsyncTuplesResourceWithRawResponse:
    def __init__(self, tuples: AsyncTuplesResource) -> None:
        self._tuples = tuples

        self.list = async_to_raw_response_wrapper(
            tuples.list,
        )


class TuplesResourceWithStreamingResponse:
    def __init__(self, tuples: TuplesResource) -> None:
        self._tuples = tuples

        self.list = to_streamed_response_wrapper(
            tuples.list,
        )


class AsyncTuplesResourceWithStreamingResponse:
    def __init__(self, tuples: AsyncTuplesResource) -> None:
        self._tuples = tuples

        self.list = async_to_streamed_response_wrapper(
            tuples.list,
        )
